package com.ynet.life.search.core;

import com.ynet.life.base.Trace;
import com.ynet.life.exception.TranFailException;
import java.io.File;
import java.io.IOException;
import org.apache.lucene.analysis.Analyzer;
import org.apache.lucene.index.CorruptIndexException;
import org.apache.lucene.index.IndexWriter;
import org.apache.lucene.search.IndexSearcher;
import org.apache.lucene.store.Directory;
import org.apache.lucene.store.NIOFSDirectory;
import org.wltea.analyzer.lucene.IKAnalyzer;
import org.wltea.analyzer.lucene.IKSimilarity;

/* loaded from: com_ynet_life_search_core.jar:com/ynet/life/search/core/IndexSourceImpl.class */
public class IndexSourceImpl implements IndexSource {
    private final Directory directory;
    private final Analyzer analyzer;
    private IndexWriter indexWriter;
    private String indexFolderFile;
    private boolean createFolder;

    public IndexSourceImpl(String indexFolderFile) throws TranFailException {
        this(indexFolderFile, false);
    }

    public IndexSourceImpl(String indexFolderFile, boolean createFolder) throws TranFailException {
        this.indexFolderFile = indexFolderFile;
        this.createFolder = createFolder;
        try {
            this.directory = NIOFSDirectory.open(new File(indexFolderFile));
            this.analyzer = new IKAnalyzer();
        } catch (IOException ioe) {
            Trace.logError("LifeSearch", String.format("搜索资源定义IndexSource对象失败: '%s'", ioe.getMessage()), ioe);
            throw new TranFailException(ioe);
        }
    }

    @Override // com.ynet.life.search.core.IndexSource
    public IndexSearcher createIndexSearcher() throws TranFailException {
        try {
            IndexSearcher indexSearch = new IndexSearcher(this.directory, true);
            indexSearch.setSimilarity(new IKSimilarity());
            return indexSearch;
        } catch (IOException ioe) {
            Trace.logError("LifeSearch", String.format("搜索时访问索引失败: '%s'", ioe.getMessage()), ioe);
            throw new TranFailException(ioe);
        } catch (CorruptIndexException cie) {
            Trace.logError("LifeSearch", String.format("索引已损坏: '%s'", cie.getMessage()), cie);
            throw new TranFailException(cie);
        }
    }

    @Override // com.ynet.life.search.core.IndexSource
    public Analyzer getAnalyzer() {
        return this.analyzer;
    }

    @Override // com.ynet.life.search.core.IndexSource
    public IndexWriter getIndexWriter() {
        if (this.indexWriter == null) {
            try {
                this.indexWriter = new IndexWriter(this.directory, this.analyzer, this.createFolder, IndexWriter.MaxFieldLength.LIMITED);
            } catch (IOException ioe) {
                Trace.logError("LifeSearch", String.format("获取IndexWriter对象失败: '%s'", ioe.getMessage()), ioe);
            }
        }
        return this.indexWriter;
    }

    @Override // com.ynet.life.search.core.IndexSource
    public void close() throws TranFailException {
        try {
            if (this.indexWriter != null) {
                this.indexWriter.close();
            }
            if (this.directory != null) {
                this.directory.close();
            }
        } catch (IOException ioe) {
            Trace.logError("LifeSearch", String.format("关闭IndexWriter、Directory失败: '%s'", ioe.getMessage()), ioe);
            throw new TranFailException(ioe);
        }
    }
}
